remove

Function remove 

pub fn remove(key: &str) -> bool
Delete the value stored under key. Returns true if a value existed and was removed, false if the key was already absent (or the delete could not be committed).

Day API ↩ Guides· daybrite.dev